#
# spec file for package python-pyelftools
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pyelftools
Version:        0.26
Release:        bp153.1.15
Summary:        Library for analyzing ELF files and DWARF debugging information
License:        SUSE-Public-Domain
Group:          Development/Languages/Python
URL:            https://github.com/eliben/pyelftools
Source:         https://files.pythonhosted.org/packages/source/p/pyelftools/pyelftools-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
pyelftools is a pure python library for analyzing ELF files and DWARF debugging information

%prep
%setup -q -n pyelftools-%{version}
# DROP THIS REMOVAL!
rm test/test_pubtypes.py
# ^^^ https://github.com/eliben/pyelftools/commit/83ad8a220d0fd7a183bf249ad8bbb681227dc266

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/readelf.py
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec test/run_all_unittests.py
%python_exec test/run_examples_test.py
# May fail due to minor differences in the output of readelf
# https://github.com/eliben/pyelftools/wiki/Hacking-guide#tests
%python_exec test/run_readelf_tests.py || :

%post
%python_install_alternative readelf.py

%postun
%python_uninstall_alternative readelf.py

%files %{python_files}
%license LICENSE
%doc CHANGES
%python_alternative %{_bindir}/readelf.py
%{python_sitelib}/*

%changelog
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Mar 19 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.26
  * Call relocation for ARM v3 (#194)
  * More complete architecture coverage for ENUM_E_MACHINE (#206)
  * Support for .debug_pubtypes and .debug_pubnames sections (#208)
  * Support for DWARF v4 location lists (#214)
  * Decode strings in dynamic string tables (#217)
  * Improve symbol table handling in dynamic segments (#219)
  * Improved handling of location information (#225)
  * Avoid deprecation warnings in Python 3.7+
  * Add DWARF v5 OPs (#240)
  * Handle many new translation forms and constants
  * Lazy DIE parsing to speed up partial parsing of DWARF info (#249)
* Sat May 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.25:
  - Make parsing of SH_TYPE and PT_TYPE fields dependent on the machine
    (e_machine header field), making it possible to support conflicting type
    enums between different machines (#71 and #121).
  - Add parsing and readelf dumping for .eh_frame (#155)
  - Support compressed sections (#152)
  - Better support for parsing core dumps (#147)
  - More comprehensive handling of ARM relocations (#121)
  - Convert all ascii encoding to utf-8 encoding (#182)
  - Don't attempt to hex/string dump SHT_NOBITS sections in readelf (#119).
  - Test with Python 3.6
  - Minor bugfixes (#118)
  - Cleanup: Use argparse instead of optparse
  - Make readelf comparison tests run in parallel using multiprocessing; cuts
    testing time 3-5x
  - Improvements in MIPS flags handling (#165)
* Fri May 18 2018 yousaf.kaukab@suse.com
- Intial package
